<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>FacebookDepreceatedMessage</name>
    <message>
        <source>Facebook XMPP support is disabled since 01.05.2015. This means Kadu will be no longer able to connect to Facebook accounts. You can leave your Facebook accounts configured for chat history or you can remove them from Kadu using Your Account dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu - Facebook</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GTalkProtocolFactory</name>
    <message>
        <source>Gmail/Google Talk ID:</source>
        <translation>Gmail/Google-Talk-ID:</translation>
    </message>
</context>
<context>
    <name>JabberActions</name>
    <message>
        <source>Resend Subscription</source>
        <translation>Abonnement erneut senden</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Abonnement entfernen</translation>
    </message>
    <message>
        <source>Ask for Subscription</source>
        <translation>Abonnement anfordern</translation>
    </message>
</context>
<context>
    <name>JabberAddAccountWidget</name>
    <message>
        <source>&lt;a href=&apos;#&apos;&gt;What is my username?&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;#&apos;&gt;Wie lautet mein Benutzername?&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Remember Password</source>
        <translation>Passwort speichern</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Konto-Identität</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Wählen Sie aus oder geben Sie eine Identität für dieses Konto ein.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Add Account</source>
        <translation>Konto hinzufügen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>JabberChangePassword</name>
    <message>
        <source>Current connection is not safe for password change. Use encrypted connection or change password on provider&apos;s site.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password change is not allowed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberChangePasswordWindow</name>
    <message>
        <source>Change Password</source>
        <translation>Passwort ändern</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>Neues Passwort</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Enter new password for your XMPP/Jabber account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Geben Sie ein neues Passwort für Ihr XMPP/Jabber-Konto ein.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Retype new password</source>
        <translation>Passwort erneut eingeben</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Changing password was successful.</source>
        <translation>Passwort erfolgreich geändert.</translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;Password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log in before changing password.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password change failed.

Error: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberContactPersonalInfoWidget</name>
    <message>
        <source>Full Name</source>
        <translation>Voller Name</translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation>Familienname</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Birthdate</source>
        <translation>Geburtsdatum</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Stadt</translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Webseite</translation>
    </message>
</context>
<context>
    <name>JabberCreateAccountWidget</name>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Retype Password</source>
        <translation>Passwort erneut eingeben</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Passwort speichern</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Konto-Identität</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Wählen Sie aus oder geben Sie eine Identität für dieses Konto ein.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Register Account</source>
        <translation>Konto erstellen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;New password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Some servers require your e-mail address during registration.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Konto löschen</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Passwort speichern</translation>
    </message>
    <message>
        <source>Change your password</source>
        <translation>Passwort ändern</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Konto-Identität</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Wählen Sie aus oder geben Sie eine Identität für dieses Konto ein.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Personal Information</source>
        <translation>Persönliche Daten</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Immer</translation>
    </message>
    <message>
        <source>When available</source>
        <translation>Wenn möglich</translation>
    </message>
    <message>
        <source>Allow plaintext authentication</source>
        <translation>Erlaube Anmeldung mit Klartext</translation>
    </message>
    <message>
        <source>Over encrypted connection</source>
        <translation>Über verschlüsselte Verbindung</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Resource</source>
        <translation>Ressource</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorität</translation>
    </message>
    <message>
        <source>Data transfer proxy</source>
        <translation>Proxy für den Datenaustausch</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Remove account</source>
        <translation>Konto entfernen</translation>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Publish system information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>XMPP Server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use custom server address/port</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use encrypted connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only in older version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use computer name as a resource</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable composing events</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your interlocutor will be notified when you are typing a message, before it is sent. And vice versa.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable chat activity events</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your interlocutor will be notified when you suspend or end conversation. And vice versa.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others can see your system name/version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confrim Account Removal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure do you want to remove account %1 (%2)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Require data transfer proxy:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log in before changing password.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberErrorService</name>
    <message>
        <source>Socket error: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server did not respond for PING message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error: %1/%2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Feature not implemented</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forbidden</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Item not found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jid malformed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not acceptable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not authorized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Payment required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recipient unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Redirect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Registration required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote server not found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove server timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Resource constraint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Service unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscription required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undefined condition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unexpected request</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberOutgoingFileTransferHandler</name>
    <message>
        <source>Aborted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is corrupted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Protocol error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberPersonalInfoWidget</name>
    <message>
        <source>Full name</source>
        <translation>Voller Name</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Family name</source>
        <translation>Familienname</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Geburtsjahr</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Stadt</translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Webseite</translation>
    </message>
</context>
<context>
    <name>JabberProtocol</name>
    <message>
        <source>Another client connected on the same resource.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberProtocolFactory</name>
    <message>
        <source>User JID:</source>
        <translation>Benutzer JID:</translation>
    </message>
</context>
<context>
    <name>JabberRegisterAccount</name>
    <message>
        <source>Internal error: invalid state</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection established.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Negotiating registration parameters.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User with this username is already registered.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Registration parameters received.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Registration at this server requires XMPP Data Forms support. Kadu currently does not support XMPP Data Forms.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1

Server message: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error: received stanza type %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSL certificate rejected</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberStreamIncomingFileTransferHandler</name>
    <message>
        <source>Aborted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is corrupted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Protocol error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberWaitForAccountRegisterWindow</name>
    <message>
        <source>Registration was successful. Your new XMPP username is %1.
Store it in a safe place along with the password.
Now please add your friends to the buddy list.</source>
        <translation>Registrierung war erfolgreich. Ihr neuer Bentzername im XMPP ist %1.
Speichern Sie es mit Ihrem Passwort nur an einem sicheren Ort.
Jetzt können Sie Ihre Freunde in die Kontaktliste aufnehmen.</translation>
    </message>
    <message>
        <source>Registering new XMPP account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Registration failed.

Server message: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting with server.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowXmlConsoleActionDescription</name>
    <message>
        <source>Show XML Console</source>
        <translation>Zeige XML-Konsole</translation>
    </message>
</context>
<context>
    <name>XmlConsole</name>
    <message>
        <source>XML Console - %1</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>